@@ -7,11 +7,14 @@ FB_tbl <- FANG %>%
 
 test_tbl <- FB_tbl
 
+# Number of tk_get_signature columns
+n <- 28
+
 test_that("tk_augment_timeseries_signature(tbl) test returns correct format.", {
     test <- tk_augment_timeseries_signature(test_tbl)
     expect_true(inherits(test, "tbl"))
     expect_equal(nrow(test), 1008)
-    expect_equal(ncol(test), 30)
+    expect_equal(ncol(test), n + 7)
 })
 
 test_xts <- FB_tbl %>%
@@ -21,7 +24,7 @@ test_that("tk_augment_timeseries_signature(xts) test returns correct format.", {
     test <- tk_augment_timeseries_signature(test_xts)
     expect_true(inherits(test, "xts"))
     expect_equal(nrow(test), 1008)
-    expect_equal(ncol(test), 26)
+    expect_equal(ncol(test), n + 3)
 })
 
 test_zoo <- FB_tbl %>%
@@ -31,7 +34,7 @@ test_that("tk_augment_timeseries_signature(zoo) test returns correct format.", {
     test <- tk_augment_timeseries_signature(test_zoo)
     expect_true(inherits(test, "zoo"))
     expect_equal(nrow(test), 1008)
-    expect_equal(ncol(test), 26)
+    expect_equal(ncol(test), n + 3)
 })
 
 test_default <- 1
